@@ -168,9 +168,9 @@ PlotDistCountNormal <- function(frm, xvar, title,
   plt + ggplot2::ggtitle(title, subtitle=subtitle)
 }
 
-#' Plot an empirical density with the matching beta distribution
+#' Plot empirical rate data as a density with the matching beta distribution
 #'
-#' Compares empirical data to a beta distribution with the same mean and standard deviation.
+#' Compares empirical rate data to a beta distribution with the same mean and standard deviation.
 #'
 #' Plots the empirical density, the theoretical matching beta, the mean value,
 #' and plus/minus one standard deviation from the mean.
@@ -186,11 +186,25 @@ PlotDistCountNormal <- function(frm, xvar, title,
 #' @examples
 #'
 #' set.seed(52523)
-#' d <- data.frame(wt=rbeta(100,shape1=1,shape2=0.5))
-#' PlotDistDensityBeta(d,'wt','example')
+#' N = 100
+#' pgray = 0.1  # rate of gray horses in the population
+#' herd_size = round(runif(N, min=25, 50))
+#' ngray = rbinom(N, herd_size, pgray)
+#' hdata = data.frame(n_gray=ngray, herd_size=herd_size)
+#'
+#' # observed rate of gray horses in each herd
+#' hdata$rate_gray = with(hdata, ngray/herd_size)
+#'
+#' title = "Observed prevalence of gray horses in population"
+#'
+#' PlotDistDensityBeta(hdata, "rate_gray", title) +
+#'   ggplot2::geom_vline(xintercept = pgray, linetype=4, color="maroon") +
+#'   ggplot2::annotate("text", x=pgray+0.01, y=0.01, hjust="left",
+#'                     label = paste("True prevalence =", pgray))
 #'
 #' # no sd lines
-#' PlotDistDensityBeta(d, 'wt', 'example', sd_color=NULL)
+#' PlotDistDensityBeta(hdata, "rate_gray", title,
+#'                     sd_color=NULL)
 #' @export
 PlotDistDensityBeta <- function(frm, xvar, title, ...,
                                 curve_color='lightgray',
@@ -215,7 +229,8 @@ PlotDistDensityBeta <- function(frm, xvar, title, ...,
   shape2 <- (1-meanx)*(meanx*(1-meanx)/varx-1)
   checkM <- shape1/(shape1+shape2)
   checkV <- shape1*shape2/((shape1+shape2)^2*(shape1+shape2+1))
-  dDist <- data.frame(x=seq(1/30,1-1/30,length.out=30))
+  # dDist <- data.frame(x=seq(1/30,1-1/30,length.out=30))
+  dDist <- data.frame(x=seq(1/200,1-1/200,length.out=100))
   colnames(dDist) <- xvar
   dDist$density <- dbeta(dDist[[xvar]],shape1=shape1,shape2=shape2)
   plt = ggplot2::ggplot() +
@@ -237,9 +252,9 @@ PlotDistDensityBeta <- function(frm, xvar, title, ...,
   plt + ggplot2::ggtitle(title)
 }
 
-#' Plot distribution details as a histogram plus matching beta
+#' Plot empirical rate data as a histogram plus matching beta
 #'
-#' Compares empirical data to a beta distribution with the same mean and standard deviation.
+#' Compares empirical rate data to a beta distribution with the same mean and standard deviation.
 #'
 #' Plots the histogram of the empirical distribution and the density of the matching beta distribution.
 #' Also plots the mean and plus/minus one standard deviation.
@@ -251,7 +266,6 @@ PlotDistDensityBeta <- function(frm, xvar, title, ...,
 #' @param xvar name of the independent (input or model) column in frame
 #' @param title title to place on plot
 #' @param ... force later arguments to bind by name
-#' @param binwidth passed to geom_histogram(). If passed in, overrides bins.
 #' @param bins passed to geom_histogram(). Default: 30
 #' @param hist_color color of empirical histogram
 #' @param beta_color color of matching theoretical beta
@@ -263,15 +277,29 @@ PlotDistDensityBeta <- function(frm, xvar, title, ...,
 #' @examples
 #'
 #' set.seed(52523)
-#' d <- data.frame(wt=rbeta(100,shape1=0.5,shape2=0.5))
-#' PlotDistHistBeta(d,'wt','example')
+#' N = 100
+#' pgray = 0.1  # rate of gray horses in the population
+#' herd_size = round(runif(N, min=25, 50))
+#' ngray = rbinom(N, herd_size, pgray)
+#' hdata = data.frame(n_gray=ngray, herd_size=herd_size)
+#'
+#' # observed rate of gray horses in each herd
+#' hdata$rate_gray = with(hdata, ngray/herd_size)
+#'
+#' title = "Observed prevalence of gray horses in population"
+#'
+#' PlotDistHistBeta(hdata, "rate_gray", title) +
+#'   ggplot2::geom_vline(xintercept = pgray, linetype=4, color="maroon") +
+#'   ggplot2::annotate("text", x=pgray+0.01, y=0.01, hjust="left",
+#'                     label = paste("True prevalence =", pgray))
 #'
 #' # no sd lines
-#' PlotDistHistBeta(d,'wt','example', sd_color=NULL)
+#' PlotDistHistBeta(hdata, "rate_gray", title,
+#'                     sd_color=NULL)
 #' @export
 PlotDistHistBeta <- function(frm, xvar, title,
                              ...,
-                             binwidth = NULL, bins = 30,
+                             bins = 30,
                              hist_color='darkgray',
                              beta_color='blue',
                              mean_color='blue',
@@ -294,14 +322,20 @@ PlotDistHistBeta <- function(frm, xvar, title,
   shape2 <- (1-meanx)*(meanx*(1-meanx)/varx-1)
   checkM <- shape1/(shape1+shape2)
   checkV <- shape1*shape2/((shape1+shape2)^2*(shape1+shape2+1))
-  dDist <- data.frame(x=seq(1/200,1-1/200,length.out=50))
+  dDist <- data.frame(x=seq(1/200,1-1/200,length.out=100))
   colnames(dDist) <- xvar
   dDist$density <- dbeta(dDist[[xvar]],shape1=shape1,shape2=shape2)
-  dDist$count <- length(x)*dDist$density/sum(dDist$densit)
+  # each observation adds 1/bins area to the histogram, as the range
+  # is 0:1. So rescale density to have similar area for presentation.
+
+  histogramArea = length(x)*(1/bins) # each obsevation grows one bin, bin-width = width([0, 1])/bins
+  dDist$count = histogramArea*dDist$density
+
+
   plt = ggplot2::ggplot() +
     ggplot2::geom_histogram(data=dPlot,
                             mapping=ggplot2::aes_string(x=xvar),
-                            binwidth = binwidth, bins = bins,
+                            bins = bins,
                             fill=hist_color, color=NA) +
     ggplot2::geom_line(data=dDist,
                        mapping=ggplot2::aes_string(x=xvar,y='count'),
